sessions_schema = [
    'amount_subtotal',
    'amount_total',
    'cancel_url',
    'customer_address_city',
    'customer_address_country',
    'customer_address_postal_code',
    'customer_address_state',
    'customer_created',
    'customer_email',
    'customer_id',
    'customer_name',
    'subscriptions'
]
